@@ -36,6 +36,9 @@ class Message(object):
         html: the HTML contents of the message. Default None.
         label_ids: the ids of labels associated with this message. Default [].
         attachments: a list of attachments for the message. Default [].
+        headers: a dict of header values. Default {}
+        cc: who the message was cc'd on the message.
+        bcc: who the message was bcc'd on the message.
 
     Attributes:
         _service (googleapiclient.discovery.Resource): the Gmail service object.
@@ -50,6 +53,9 @@ class Message(object):
         html (str): the HTML contents of the message.
         label_ids (List[str]): the ids of labels associated with this message.
         attachments (List[Attachment]): a list of attachments for the message.
+        headers (dict): a dict of header values.
+        cc (List[str]): who the message was cc'd on the message.
+        bcc (List[str]): who the message was bcc'd on the message.
 
     """
 
@@ -69,7 +75,9 @@ class Message(object):
         html: Optional[str] = None,
         label_ids: Optional[List[str]] = None,
         attachments: Optional[List[Attachment]] = None,
-        headers: Optional[dict] = None
+        headers: Optional[dict] = None,
+        cc: Optional[List[str]] = None,
+        bcc: Optional[List[str]] = None
     ) -> None:
         self._service = service
         self.creds = creds
@@ -83,9 +91,11 @@ class Message(object):
         self.snippet = snippet
         self.plain = plain
         self.html = html
-        self.label_ids = label_ids if label_ids is not None else []
-        self.attachments = attachments if attachments is not None else []
-        self.headers = headers if headers else {}
+        self.label_ids = label_ids or []
+        self.attachments = attachments or []
+        self.headers = headers or {}
+        self.cc = cc or []
+        self.bcc = bcc or []
 
     @property
     def service(self) -> 'googleapiclient.discovery.Resource':
